@@ -1,6 +1,6 @@
 package Image::Magick;
 
-# Released Feb. 17, 1997  by Kyle Shorter (magick@sympatico.org)
+# Released Feb. 17, 1997  by Kyle Shorter (magick@wizards.dupont.com)
 # Public Domain
 
 use strict;
@@ -18,13 +18,15 @@ require AutoLoader;
 # Do not simply export all your public functions/methods/constants.
 @EXPORT =
   qw(
-    ResourceLimitError XServerError OptionError 
-    Success
-    ResourceLimitWarning XServerWarning OptionWarning PluginWarning
-	MissingPluginWarning CorruptImageWarning FileOpenWarning
+      ResourceLimitWarning XServerWarning OptionWarning DelegateWarning
+      MissingDelegateWarning CorruptImageWarning FileOpenWarning
+      BlobWarning CacheWarning StreamWarning FatalException
+      ResourceLimitError XServerError OptionError DelegateError
+      MissingDelegateError CorruptImageError FileOpenError BlobError
+      CacheError StreamError Success Transparent Opaque MaxRGB
     );
 
-$VERSION = '1.39';
+$VERSION = '5.41';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -40,7 +42,8 @@ sub AUTOLOAD {
 	    goto &AutoLoader::AUTOLOAD;
 	}
 	else {
-		croak "Your vendor has not defined Image::Magick macro $constname";
+	    my($pack,$file,$line) = caller;
+	    die "Your vendor has not defined PerlMagick macro $pack\:\:$constname, used at $file line $line.\n";
 	}
     }
     eval "sub $AUTOLOAD { $val }";
@@ -61,6 +64,16 @@ sub new
     return $self;
 }
 
+sub New
+{
+    my $this = shift;
+    my $class = ref($this) || $this || "Image::Magick";
+    my $self = [ ];
+    bless $self, $class;
+    $self->set(@_) if @_;
+    return $self;
+}
+
 # Autoload methods go after =cut, and are processed by the autosplit program.
 
 1;
@@ -85,12 +98,12 @@ Image::Magick - Perl extension for calling ImageMagick's libmagick routines
 
 This Perl extension allows the reading, manipulation and writing of
 a large number of image file formats using the magick library from
-ImageMagick by John Cristy (cristy@mystic.es.dupont.com).  It was originally
+ImageMagick by John Cristy (magick@wizards.dupont.com).  It was originally
 developed to be used by CGI scripts for Web pages.
 
 A Web page has been set up for this extension. See:
 
-	http://www.wizards.dupont.com/cristy/www/perl.html
+	http://www.simplesystems.org/ImageMagick/www/perl.html
 
 =head1 AUTHOR
 
